pub enum GridIndexing {
Matrix,
Cartesian,
}Available on crate feature
api only.Expand description
Enum to specify index cardinal layout.
Variants
Matrix
Dimensions are in the same order as the cardinality of the inputs. Equivalent to “ij” indexing in NumPy and PyTorch.
Cartesian
The same as Matrix, but the first two dimensions are swapped. Equivalent to “xy” indexing in NumPy and PyTorch.