pub struct Transaction<B: Backend> { /* private fields */ }Available on crate feature
api only.Expand description
A transaction can read multiple tensors at once with a single operation improving compute utilization with optimized laziness.
Example
ⓘ
let [output_data, loss_data, targets_data] = Transaction::default()
.register(output)
.register(loss)
.register(targets)
.execute()
.try_into()
.expect("Correct amount of tensor data");Implementations
Sourceimpl<B: Backend> Transaction<B>
impl<B: Backend> Transaction<B>
Sourcepub fn register<const D: usize, K: TransactionOp<B> + BasicOps<B>>(
self,
tensor: Tensor<B, D, K>,
) -> Self
pub fn register<const D: usize, K: TransactionOp<B> + BasicOps<B>>( self, tensor: Tensor<B, D, K>, ) -> Self
Add a tensor to the transaction to be read.
Sourcepub fn execute(self) -> Vec<TensorData>
pub fn execute(self) -> Vec<TensorData>
Executes the transaction synchronously and returns the data in the same order in which they were registered.
Sourcepub fn try_execute(self) -> Result<Vec<TensorData>, ExecutionError>
pub fn try_execute(self) -> Result<Vec<TensorData>, ExecutionError>
Executes the transaction synchronously and returns the data in the same order in which they were registered.
Returns
Any error that might have occurred since the last time the device was synchronized.
Sourcepub async fn execute_async(self) -> Result<Vec<TensorData>, ExecutionError>
pub async fn execute_async(self) -> Result<Vec<TensorData>, ExecutionError>
Executes the transaction asynchronously and returns the data in the same order in which they were registered.