Module backend

Module backend 

Backend trait and required types.

Re-exports

pub use crate::ops;
pub use crate::device::*;
pub use crate::primitive::*;

Structs

BackTrace
Contains the backtrace information if available.

Enums

DTypeUsage
Describes how a data type can be used on a given device.
ExecutionError
An error that can happen when syncing a device.

Traits

AutodiffBackend
Trait that allows a backend to support autodiff.
Backend
This trait defines all types and functions needed for a backend to be used with ruda.
BackendTypes
The mapping of types used by Backend and traits like Numeric, BasicOps

Type Aliases

DTypeUsageSet
A set of DTypeUsage representing the total capabilities of a data type on a device.