pub enum DType {
Show 15 variants
F64,
F32,
Flex32,
F16,
BF16,
I64,
I32,
I16,
I8,
U64,
U32,
U16,
U8,
Bool(BoolStore),
QFloat(QuantScheme),
}Variants
Implementations
Sourceimpl DType
impl DType
Sourcepub const fn size(&self) -> usize
Available on crate feature api only.
pub const fn size(&self) -> usize
api only.Returns the size of a type in bytes.
Sourcepub fn is_float(&self) -> bool
Available on crate feature api only.
pub fn is_float(&self) -> bool
api only.Returns true if the data type is a floating point type.
Sourcepub fn is_int(&self) -> bool
Available on crate feature api only.
pub fn is_int(&self) -> bool
api only.Returns true if the data type is a signed integer type.
Sourcepub fn is_uint(&self) -> bool
Available on crate feature api only.
pub fn is_uint(&self) -> bool
api only.Returns true if the data type is an unsigned integer type.
Sourcepub fn is_bool(&self) -> bool
Available on crate feature api only.
pub fn is_bool(&self) -> bool
api only.Returns true if the data type is a boolean type