Module ops

Module ops 

Modules

attention
Module with attention operations.
conv
Module with convolution operations.
ctc
Module with CTC loss operations.
grid_sample
Module for grid_sample operations
linear
Module with linear operations.
pool
Module with pooling operations.
unfold
Module with unfold operations.

Macros

dequant_op_flow
Automatically applies dequantization -> float operation [-> quantization].
dequant_op_quant
Automatically applies dequantization -> float operation -> quantization.

Structs

AttentionModuleOptions
Options for attention.
Conv2dBackward
Gradient computed during the backward pass for each tensor used by conv2d.
Conv3dBackward
Gradient computed during the backward pass for each tensor used by conv3d.
ConvOptions
Convolution options.
ConvTransposeOptions
Transposed convolution options.
CsrAddition
DeformConv2dBackward
Gradient computed during the backward pass for each tensor used by deform_conv2d.
DeformConvOptions
Convolution options.
GridSampleOptions
Options for grid sampling operations.
InterpolateBackward
Gradient computed during the backward pass for each tensor used by interpolate.
InterpolateOptions
Interpolation options.
MaxPool1dBackward
Gradient computed during the backward pass for each tensor used by max_pool1d.
MaxPool1dWithIndices
Results from max_pool1d.
MaxPool2dBackward
Gradient computed during the backward pass for each tensor used by max_pool2d.
MaxPool2dWithIndices
Results from max_pool2d.
PaddedConvOptions
Convolution options with support for asymmetric padding.
TransactionPrimitive
Contains all tensor primitives that are going to be read.
TransactionPrimitiveData
Contains all data related to a transaction.
UnfoldOptions
Unfold operation options.

Enums

GridSamplePaddingMode
Padding mode for grid sampling when coordinates are out of bounds.
InterpolateMode
Algorithm used for upsampling.
PadMode
Padding mode for tensor pad operations.

Traits

ActivationOps
Activation function operations.
BoolTensorOps
Bool Tensor API for basic operations, see Tensor for documentation on each function.
FloatTensorOps
Operations on float tensors.
IntTensorOps
Int Tensor API for basic and numeric operations, see Tensor for documentation on each function.
ModuleOps
Module operations trait.
QTensorOps
Operations on quantized tensors.
SparseOps
TransactionOps
Operations that are sync by nature and that can be batch together in transactions to improve compute utilization with efficient laziness.