Module slice

Module slice 

Slice utilities.

Macros

s
Slice argument constructor for tensor indexing.

Structs

Slice
A slice specification for a single tensor dimension.
SliceIter
Defines an Iterator over a Slice.

Traits

SliceArg
Trait for slice arguments that can be converted into an array of slices. This allows the slice method to accept both single slices (from s![..]) and arrays of slices (from s![.., ..] or [0..5, 1..3]).
SliceOps
Slice-related ops on Shape