TensorData

Struct TensorData 

pub struct TensorData {
    pub bytes: Bytes,
    pub shape: Shape,
    pub dtype: DType,
}
Data structure for tensors.

Fields

bytes: Bytes

The values of the tensor (as bytes).

shape: Shape

The shape of the tensor.

dtype: DType

The data type of the tensor.

Implementations

Source

impl TensorData

pub fn rank(&self) -> usize

Available on crate feature api only.

Returns the rank (the number of dimensions).

pub fn num_elements(&self) -> usize

Available on crate feature api only.

Returns the total number of elements of the tensor data.

Source

impl TensorData

pub fn assert_eq(&self, other: &TensorData, strict: bool)

Available on crate feature api only.

Asserts the data is equal to another data.

Arguments
  • other - The other data.
  • strict - If true, the data types must the be same. Otherwise, the comparison is done in the current data type.
Panics

Panics if the data is not equal.

pub fn assert_approx_eq<F>(&self, other: &TensorData, tolerance: Tolerance<F>)
where F: Float + Element,

Available on crate feature api only.

Asserts the data is approximately equal to another data.

Arguments
  • other - The other data.
  • tolerance - The tolerance of the comparison.
Panics

Panics if the data is not approximately equal.

pub fn assert_within_range<E>(&self, range: Range<E>)
where E: ElementOrdered,

Available on crate feature api only.

Asserts each value is within a given range.

Arguments
  • range - The range.
Panics

If any value is not within the half-open range bounded inclusively below and exclusively above (start..end).

pub fn assert_within_range_inclusive<E>(&self, range: RangeInclusive<E>)
where E: ElementOrdered,

Available on crate feature api only.

Asserts each value is within a given inclusive range.

Arguments
  • range - The range.
Panics

If any value is not within the half-open range bounded inclusively (start..=end).

Source

impl TensorData

pub fn new<E, S>(value: Vec<E>, shape: S) -> TensorData
where E: Element, S: Into<Shape>,

Available on crate feature api only.

Creates a new tensor data structure.

pub fn quantized<E, S>( value: Vec<E>, shape: S, scheme: QuantScheme, qparams: &[f32], ) -> TensorData
where E: Element, S: Into<Shape>,

Available on crate feature api only.

Creates a new quantized tensor data structure.

pub fn from_bytes<S>(bytes: Bytes, shape: S, dtype: DType) -> TensorData
where S: Into<Shape>,

Available on crate feature api only.

Creates a new tensor data structure from raw bytes.

pub fn from_bytes_vec<S>(bytes: Vec<u8>, shape: S, dtype: DType) -> TensorData
where S: Into<Shape>,

Available on crate feature api only.

Creates a new tensor data structure from raw bytes stored in a vector.

Prefer TensorData::new or TensorData::quantized over this method unless you are certain that the bytes representation is valid.

Source

impl TensorData

pub fn convert<E>(self) -> TensorData
where E: Element,

Available on crate feature api only.

Converts the data to a different element type.

pub fn convert_dtype(self, dtype: DType) -> TensorData

Available on crate feature api only.

Converts the data to a different element type.

Source

impl TensorData

pub fn random<E, R, S>( shape: S, distribution: Distribution, rng: &mut R, ) -> TensorData
where E: Element, R: Rng, S: Into<Shape>,

Available on crate feature api only.

Populates the data with random values.

pub fn zeros<E, S>(shape: S) -> TensorData
where E: Element, S: Into<Shape>,

Available on crate feature api only.

Populates the data with zeros.

pub fn ones<E, S>(shape: S) -> TensorData
where E: Element, S: Into<Shape>,

Available on crate feature api only.

Populates the data with ones.

pub fn full<E, S>(shape: S, fill_value: E) -> TensorData
where E: Element, S: Into<Shape>,

Available on crate feature api only.

Populates the data with the given value

pub fn full_dtype<E, S>(shape: S, fill_value: E, dtype: DType) -> TensorData
where E: Into<Scalar>, S: Into<Shape>,

Available on crate feature api only.

Populates the data with the given value

Source

impl TensorData

pub fn iter<E>(&self) -> Box<dyn Iterator<Item = E> + '_>
where E: Element,

Available on crate feature api only.

Returns an iterator over the values of the tensor data.

Source

impl TensorData

pub fn as_slice<E>(&self) -> Result<&[E], DataError>
where E: Element,

Available on crate feature api only.

Returns the immutable slice view of the tensor data.

pub fn as_mut_slice<E>(&mut self) -> Result<&mut [E], DataError>
where E: Element,

Available on crate feature api only.

Returns the mutable slice view of the tensor data.

Panics

If the target element type is different from the stored element type.

pub fn to_vec<E>(&self) -> Result<Vec<E>, DataError>
where E: Element,

Available on crate feature api only.

Returns the tensor data as a vector of scalar values.

pub fn into_vec<E>(self) -> Result<Vec<E>, DataError>
where E: Element,

Available on crate feature api only.

Returns the tensor data as a vector of scalar values.

pub fn as_bytes(&self) -> &[u8] ⓘ

Available on crate feature api only.

Returns the data as a slice of bytes.

pub fn into_bytes(self) -> Bytes

Available on crate feature api only.

Returns the bytes representation of the data.