Backend tensor primitives and operations.
Modules
- quantization
- Tensor quantization module.
Structs
- Bool
- A type-level representation of the kind of a bool tensor.
- Float
- A type-level representation of the kind of a float tensor
- Int
- A type-level representation of the kind of a int tensor.
- Tensor
Container - Contains tensor of arbitrary dimension.
Enums
- Indexing
Update Op - Computation to be used to update the existing values in indexed assignment operations (scatter/select).
Traits
- Basic
Autodiff Ops - Trait that list all operations that can be applied on all tensors on an autodiff backend.
- Basic
Ops - Trait that list all operations that can be applied on all tensors.
- Float
Math Ops - Trait that lists some floating-point mathematical operations are common to all float-like dtypes.
- Numeric
- Trait that list all operations that can be applied on all numerical tensors.
- Ordered
- Trait that list all operations that can be applied on all numerical tensors whose elements have a well-defined ordering.
- Tensor
Kind - A type-level representation of the kind of a tensor. Metadata access is lazy.
- Transaction
Op - Trait for the one basic op that still requires Backend
Type Aliases
- Bool
Elem - Boolean element type used by backend.
- Bool
Tensor - Boolean tensor primitive type used by the backend.
- Device
- Device type used by the backend.
- Float
Elem - Float element type used by backend.
- Float
Tensor - Float tensor primitive type used by the backend.
- IntElem
- Integer element type used by backend.
- IntTensor
- Integer tensor primitive type used by the backend.
- Quantized
Tensor - Quantized tensor primitive type used by the backend.