Backend trait and required types.
Re-exports
Structs
- Back
Trace - Contains the backtrace information if available.
Enums
- DType
Usage - Describes how a data type can be used on a given device.
- Execution
Error - An error that can happen when syncing a device.
Traits
- Autodiff
Backend - Trait that allows a backend to support autodiff.
- Backend
- This trait defines all types and functions needed for a backend to be used with ruda.
- Backend
Types - The mapping of types used by Backend and traits like Numeric, BasicOps
Type Aliases
- DType
Usage Set - A set of DTypeUsage representing the total capabilities of a data type on a device.