pub struct TensorData {
pub bytes: Bytes,
pub shape: Shape,
pub dtype: DType,
}Expand description
Data structure for tensors.
Fields
bytes: BytesThe values of the tensor (as bytes).
shape: ShapeThe shape of the tensor.
dtype: DTypeThe data type of the tensor.
Implementations
Sourceimpl TensorData
impl TensorData
Sourceimpl TensorData
impl TensorData
Sourcepub fn assert_eq(&self, other: &TensorData, strict: bool)
Available on crate feature api only.
pub fn assert_eq(&self, other: &TensorData, strict: bool)
api only.Sourcepub fn assert_approx_eq<F>(&self, other: &TensorData, tolerance: Tolerance<F>)
Available on crate feature api only.
pub fn assert_approx_eq<F>(&self, other: &TensorData, tolerance: Tolerance<F>)
api only.Sourcepub fn assert_within_range<E>(&self, range: Range<E>)where
E: ElementOrdered,
Available on crate feature api only.
pub fn assert_within_range<E>(&self, range: Range<E>)where
E: ElementOrdered,
api only.Sourcepub fn assert_within_range_inclusive<E>(&self, range: RangeInclusive<E>)where
E: ElementOrdered,
Available on crate feature api only.
pub fn assert_within_range_inclusive<E>(&self, range: RangeInclusive<E>)where
E: ElementOrdered,
api only.Sourceimpl TensorData
impl TensorData
Sourcepub fn new<E, S>(value: Vec<E>, shape: S) -> TensorData
Available on crate feature api only.
pub fn new<E, S>(value: Vec<E>, shape: S) -> TensorData
api only.Creates a new tensor data structure.
Sourcepub fn quantized<E, S>(
value: Vec<E>,
shape: S,
scheme: QuantScheme,
qparams: &[f32],
) -> TensorData
Available on crate feature api only.
pub fn quantized<E, S>( value: Vec<E>, shape: S, scheme: QuantScheme, qparams: &[f32], ) -> TensorData
api only.Creates a new quantized tensor data structure.
Sourcepub fn from_bytes<S>(bytes: Bytes, shape: S, dtype: DType) -> TensorData
Available on crate feature api only.
pub fn from_bytes<S>(bytes: Bytes, shape: S, dtype: DType) -> TensorData
api only.Creates a new tensor data structure from raw bytes.
Sourcepub fn from_bytes_vec<S>(bytes: Vec<u8>, shape: S, dtype: DType) -> TensorData
Available on crate feature api only.
pub fn from_bytes_vec<S>(bytes: Vec<u8>, shape: S, dtype: DType) -> TensorData
api only.Creates a new tensor data structure from raw bytes stored in a vector.
Prefer TensorData::new or TensorData::quantized over this method unless you are
certain that the bytes representation is valid.
Sourceimpl TensorData
impl TensorData
Sourcepub fn convert<E>(self) -> TensorDatawhere
E: Element,
Available on crate feature api only.
pub fn convert<E>(self) -> TensorDatawhere
E: Element,
api only.Converts the data to a different element type.
Sourcepub fn convert_dtype(self, dtype: DType) -> TensorData
Available on crate feature api only.
pub fn convert_dtype(self, dtype: DType) -> TensorData
api only.Converts the data to a different element type.
Sourceimpl TensorData
impl TensorData
Sourcepub fn random<E, R, S>(
shape: S,
distribution: Distribution,
rng: &mut R,
) -> TensorData
Available on crate feature api only.
pub fn random<E, R, S>( shape: S, distribution: Distribution, rng: &mut R, ) -> TensorData
api only.Populates the data with random values.
Sourcepub fn zeros<E, S>(shape: S) -> TensorData
Available on crate feature api only.
pub fn zeros<E, S>(shape: S) -> TensorData
api only.Populates the data with zeros.
Sourcepub fn ones<E, S>(shape: S) -> TensorData
Available on crate feature api only.
pub fn ones<E, S>(shape: S) -> TensorData
api only.Populates the data with ones.
Sourcepub fn full<E, S>(shape: S, fill_value: E) -> TensorData
Available on crate feature api only.
pub fn full<E, S>(shape: S, fill_value: E) -> TensorData
api only.Populates the data with the given value
Sourcepub fn full_dtype<E, S>(shape: S, fill_value: E, dtype: DType) -> TensorData
Available on crate feature api only.
pub fn full_dtype<E, S>(shape: S, fill_value: E, dtype: DType) -> TensorData
api only.Populates the data with the given value
Sourceimpl TensorData
impl TensorData
Sourceimpl TensorData
impl TensorData
Sourcepub fn as_slice<E>(&self) -> Result<&[E], DataError>where
E: Element,
Available on crate feature api only.
pub fn as_slice<E>(&self) -> Result<&[E], DataError>where
E: Element,
api only.Returns the immutable slice view of the tensor data.
Sourcepub fn as_mut_slice<E>(&mut self) -> Result<&mut [E], DataError>where
E: Element,
Available on crate feature api only.
pub fn as_mut_slice<E>(&mut self) -> Result<&mut [E], DataError>where
E: Element,
api only.Returns the mutable slice view of the tensor data.
Panics
If the target element type is different from the stored element type.
Sourcepub fn to_vec<E>(&self) -> Result<Vec<E>, DataError>where
E: Element,
Available on crate feature api only.
pub fn to_vec<E>(&self) -> Result<Vec<E>, DataError>where
E: Element,
api only.Returns the tensor data as a vector of scalar values.
Sourcepub fn into_vec<E>(self) -> Result<Vec<E>, DataError>where
E: Element,
Available on crate feature api only.
pub fn into_vec<E>(self) -> Result<Vec<E>, DataError>where
E: Element,
api only.Returns the tensor data as a vector of scalar values.
Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
Available on crate feature api only.
pub fn as_bytes(&self) -> &[u8] ⓘ
api only.Returns the data as a slice of bytes.
Sourcepub fn into_bytes(self) -> Bytes
Available on crate feature api only.
pub fn into_bytes(self) -> Bytes
api only.Returns the bytes representation of the data.