Module tensor

Module tensor 

Backend tensor primitives and operations.

Modules

quantization
Tensor quantization module.

Structs

Bool
A type-level representation of the kind of a bool tensor.
Float
A type-level representation of the kind of a float tensor
Int
A type-level representation of the kind of a int tensor.
TensorContainer
Contains tensor of arbitrary dimension.

Enums

IndexingUpdateOp
Computation to be used to update the existing values in indexed assignment operations (scatter/select).

Traits

BasicAutodiffOps
Trait that list all operations that can be applied on all tensors on an autodiff backend.
BasicOps
Trait that list all operations that can be applied on all tensors.
FloatMathOps
Trait that lists some floating-point mathematical operations are common to all float-like dtypes.
Numeric
Trait that list all operations that can be applied on all numerical tensors.
Ordered
Trait that list all operations that can be applied on all numerical tensors whose elements have a well-defined ordering.
TensorKind
A type-level representation of the kind of a tensor. Metadata access is lazy.
TransactionOp
Trait for the one basic op that still requires Backend

Type Aliases

BoolElem
Boolean element type used by backend.
BoolTensor
Boolean tensor primitive type used by the backend.
Device
Device type used by the backend.
FloatElem
Float element type used by backend.
FloatTensor
Float tensor primitive type used by the backend.
IntElem
Integer element type used by backend.
IntTensor
Integer tensor primitive type used by the backend.
QuantizedTensor
Quantized tensor primitive type used by the backend.